@@ -5,14 +5,19 @@
  *   2. ESL_GENCODE genetic code object
  *   3. Reading and writing genetic codes in NCBI format
  *   4. DNA->protein digital translation, allowing ambiguity chars
- *   5. Functions fo/////ting/destroying ESL_TRANS_WORKSTATE
+ *   5. Functions for creating/destroying ESL_GENCODE_WORKSTATE
  *   6. Functions for processing ORFs
  *   7. Debugging/development utilities
  *   8. Unit tests
  *   9. Test driver
  *   10. Examples
+ *   
+ * To do:  
+ *   - Remove dependency on ESL_GETOPTS. Use a configuration params _CFG   
+ *     structure instead. (See `msaweight` for example).
+ *     [xref SRE:2019/0415-easel-tech-tree-v3]
  */
-#include "esl_config.h"
+#include <esl_config.h>
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -21,7 +26,10 @@
 #include "easel.h"
 #include "esl_alphabet.h"
 #include "esl_fileparser.h"
+#include "esl_getopts.h"     // problematic. See TO DO note.
 #include "esl_regexp.h"
+#include "esl_sq.h"
+#include "esl_sqio.h"
 
 #include "esl_gencode.h"
 
@@ -722,7 +730,7 @@ esl_gencode_IsInitiator(const ESL_GENCODE *gcode, ESL_DSQ *dsqp)
 
 
 /*****************************************************************
- * 5. Functions for creating/destroying ESL_TRANS_WORKSTATE
+ * 5. Functions for creating/destroying ESL_GENCODE_WORKSTATE
  *****************************************************************/
 void
 esl_gencode_WorkstateDestroy(ESL_GENCODE_WORKSTATE *wrk)
@@ -1068,7 +1076,7 @@ utest_ReadWrite(void)
  *****************************************************************/
 #ifdef eslGENCODE_TESTDRIVE
 
-#include "esl_config.h"
+#include <esl_config.h>
 
 #include "esl_gencode.h"
 
