@@ -17,7 +17,7 @@
  *   www.json.org
  *   tools.ietf.org/html/rfc8259 
  */
-#include "esl_config.h"
+#include <esl_config.h>
 
 #include <stdio.h>
 #include <ctype.h>
@@ -744,14 +744,14 @@ esl_json_Validate(const ESL_JSON *pi, const ESL_BUFFER *bf, char *errbuf)
 	  if (pos2 >= bf->n) ESL_FAIL(eslFAIL, errbuf, "bad end pos, tok %d",   i);
 
 	  switch (tok->type) {
-	  case eslJSON_OBJECT:  if (bf->mem[pos1]   != '{' || bf->mem[pos2]   != '}')        ESL_FAIL(eslFAIL, errbuf, "object closing brackets missing, tok %d", i); break;
-	  case eslJSON_ARRAY:   if (bf->mem[pos1]   != '[' || bf->mem[pos2]   != ']')        ESL_FAIL(eslFAIL, errbuf, "array closing brackets missing, tok %d",  i); break;
-	  case eslJSON_KEY:     if (bf->mem[pos1-1] != '"' || bf->mem[pos2+1] != '"')        ESL_FAIL(eslFAIL, errbuf, "key quotes missing, tok %d",              i); break;
-	  case eslJSON_STRING:  if (bf->mem[pos1-1] != '"' || bf->mem[pos2+1] != '"')        ESL_FAIL(eslFAIL, errbuf, "string quotes missing, tok %d",           i); break;
-	  case eslJSON_NUMBER:  if (! esl_mem_IsReal(bf->mem + pos1, pos2-pos1+1))           ESL_FAIL(eslFAIL, errbuf, "number isn't a number, tok %d",           i); break;
+	  case eslJSON_OBJECT:  if (bf->mem[pos1]   != '{' || bf->mem[pos2]   != '}')       { ESL_FAIL(eslFAIL, errbuf, "object closing brackets missing, tok %d", i); } break;
+          case eslJSON_ARRAY:   if (bf->mem[pos1]   != '[' || bf->mem[pos2]   != ']')       { ESL_FAIL(eslFAIL, errbuf, "array closing brackets missing, tok %d",  i); } break;
+          case eslJSON_KEY:     if (bf->mem[pos1-1] != '"' || bf->mem[pos2+1] != '"')       { ESL_FAIL(eslFAIL, errbuf, "key quotes missing, tok %d",              i); } break;
+          case eslJSON_STRING:  if (bf->mem[pos1-1] != '"' || bf->mem[pos2+1] != '"')       { ESL_FAIL(eslFAIL, errbuf, "string quotes missing, tok %d",           i); } break;
+          case eslJSON_NUMBER:  if (! esl_mem_IsReal(bf->mem + pos1, pos2-pos1+1))          { ESL_FAIL(eslFAIL, errbuf, "number isn't a number, tok %d",           i); } break;
 	  case eslJSON_BOOLEAN: if (! esl_memstrcmp(bf->mem + pos1, pos2-pos1+1, "true")  &&
-				    ! esl_memstrcmp(bf->mem + pos1, pos2-pos1+1, "false"))   ESL_FAIL(eslFAIL, errbuf, "boolean isn't a boolean, tok %d",         i); break;
-	  case eslJSON_NULL:    if (! esl_memstrcmp(bf->mem + pos1, pos2-pos1+1, "null"))    ESL_FAIL(eslFAIL, errbuf, "null isn't null, tok %d",                 i); break;
+				    ! esl_memstrcmp(bf->mem + pos1, pos2-pos1+1, "false"))  { ESL_FAIL(eslFAIL, errbuf, "boolean isn't a boolean, tok %d",         i); } break;
+          case eslJSON_NULL:    if (! esl_memstrcmp(bf->mem + pos1, pos2-pos1+1, "null"))   { ESL_FAIL(eslFAIL, errbuf, "null isn't null, tok %d",                 i); } break;
 	  default: ESL_FAIL(eslFAIL, errbuf, "no such state type %d, tok %d", (int) tok->type, i);
           }
 	}
@@ -1251,7 +1251,7 @@ utest_read_float(void)
       if (( status = esl_json_ReadFloat(pi, 2, bf, &val)) != tests[i].status) esl_fatal(msg);
       if (tests[i].rtol == 0.0) {
 	if (val != tests[i].trueval) esl_fatal(msg);  // includes inf==inf test
-      } else if (esl_FCompareNew(tests[i].trueval, val, tests[i].rtol, tests[i].atol) != eslOK) esl_fatal(msg);
+      } else if (esl_FCompare(tests[i].trueval, val, tests[i].rtol, tests[i].atol) != eslOK) esl_fatal(msg);
 
       esl_buffer_Close(bf);
       esl_json_Destroy(pi);
@@ -1281,7 +1281,7 @@ utest_read_float_err(ESL_RANDOMNESS *rng, int allow_badluck)
   for (trial = 0; trial < 10000; trial++)
     {
       if ( esl_rnd_floatstring(rng, s)            != eslOK) esl_fatal(msg);
-      if ( sprintf(sj, "{ \"a\" : %s }", s)       < 0)      esl_fatal(msg);
+      if ( snprintf(sj, 64, "{ \"a\" : %s }", s)  < 0)      esl_fatal(msg);
       if ( esl_buffer_OpenMem(sj, -1, &bf)        != eslOK) esl_fatal(msg);
       if ( esl_json_Parse(bf, &pi)                != eslOK) esl_fatal(msg);
       if ( esl_json_ReadFloat(pi, 2, bf, &(v2.f)) != eslOK) esl_fatal(msg);
