@@ -2,7 +2,7 @@
  */
 #ifndef eslMSACLUSTER_INCLUDED
 #define eslMSACLUSTER_INCLUDED
-#include "esl_config.h"
+#include <esl_config.h>
 #include "esl_msa.h"
 
 extern int esl_msacluster_SingleLinkage(const ESL_MSA *msa, double maxid, 
