@@ -13,7 +13,7 @@
  *  10. Test driver.
  *  11. Example.
  */
-#include "esl_config.h"
+#include <esl_config.h>
 
 #include <stdlib.h>
 #include <string.h>
@@ -759,13 +759,15 @@ esl_rsq_CMarkov1(ESL_RANDOMNESS *r, const char *s, char *markoved)
  *           has a digital alphabet.) The caller must provide a <dsq>
  *           allocated for at least <L+2> residues of type <ESL_DSQ>,
  *           room for <L> residues and leading/trailing digital sentinel bytes.
- *           
+ * 
  *           <esl_rsq_xfIID()> does the same, but for a
  *           single-precision float vector <p> rather than a
  *           double-precision vector <p>.
+ * 
+ *           As a special case, if <p> is <NULL>, sample residues uniformly.
  *
  * Args:     r         - ESL_RANDOMNESS object
- *           p         - probability distribution [0..n-1]
+ *           p         - probability distribution [0..n-1] (or NULL for uniform)
  *           K         - number of symbols in alphabet
  *           L         - length of generated sequence
  *           ret_s     - RETURN: the generated sequence. 
@@ -780,7 +782,7 @@ esl_rsq_xIID(ESL_RANDOMNESS *r, const double *p, int K, int L, ESL_DSQ *dsq)
 
   dsq[0] = dsq[L+1] = eslDSQ_SENTINEL;
   for (x = 1; x <= L; x++) 
-    dsq[x] = esl_rnd_DChoose(r,p,K);
+    dsq[x] = p ? esl_rnd_DChoose(r,p,K) : esl_rnd_Roll(r,K);
   return eslOK;
 }
 int
@@ -790,13 +792,13 @@ esl_rsq_xfIID(ESL_RANDOMNESS *r, const float *p, int K, int L, ESL_DSQ *dsq)
 
   dsq[0] = dsq[L+1] = eslDSQ_SENTINEL;
   for (x = 1; x <= L; x++) 
-    dsq[x] = esl_rnd_FChoose(r,p,K);
+    dsq[x] = p ? esl_rnd_FChoose(r,p,K) : esl_rnd_Roll(r,K);
   return eslOK;
 }
 
 
 /* Function:  esl_rsq_SampleDirty()
- * Synopsis:  Sample a digital sequence, including noncanonicals.
+ * Synopsis:  Sample a digital sequence with noncanonicals, optionally gaps.
  * Incept:    SRE, Wed Feb 17 10:57:28 2016 [H1/76]
  *
  * Purpose:   Using random number generator <rng>, use probability
@@ -815,7 +817,8 @@ esl_rsq_xfIID(ESL_RANDOMNESS *r, const float *p, int K, int L, ESL_DSQ *dsq)
  *            "alignment", <p[K]> is nonzero.
  *            
  *            If <p> is <NULL>, then we sample a probability vector
- *            according to the following rules. 
+ *            according to the following rules, which generates
+ *            *ungapped* dirtied random sequences:
  *               1. Sample pc, the probability of canonical
  *                  vs. noncanonical residues, uniformly on [0,1).
  *               2. Sample a p[] uniformly for canonical residues
@@ -1354,7 +1357,7 @@ esl_rsq_XMarkov1(ESL_RANDOMNESS *r, const ESL_DSQ *dsq, int L, int K, ESL_DSQ *m
 #ifdef eslRANDOMSEQ_STATS
 /* gcc -g -Wall -o randomseq_stats -L. -I. -DeslRANDOMSEQ_STATS esl_randomseq.c -leasel -lm
  */
-#include "esl_config.h"
+#include <esl_config.h>
 
 #include <stdio.h>
 #include <string.h>
@@ -2015,7 +2018,7 @@ utest_markov1_bug(ESL_RANDOMNESS *r)
 /* gcc -g -Wall -o randomseq_utest -L. -I. -DeslRANDOMSEQ_TESTDRIVE esl_randomseq.c -leasel -lm
  */
 
-#include "esl_config.h"
+#include <esl_config.h>
 
 #include <stdio.h>
 #include <string.h>
