@@ -20,7 +20,7 @@
  * remain. Thanks Don!
  *
  */
-#include "esl_config.h"
+#include <esl_config.h>
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -767,7 +767,7 @@ esl_sqio_DecodeFormat(int fmt)
  *            be able to read the entire thing again.
  *            
  *            After <esl_sqfile_Position()> is called on a nonzero
- *            <offset>, and other bookkeeping information is unknown.
+ *            <offset>, other bookkeeping information is unknown.
  *            If caller knows it, it should set it explicitly.
  *            
  *            See the SSI module for manipulating offsets and indices.
@@ -1843,18 +1843,16 @@ make_ssi_index(ESL_ALPHABET *abc, const char *tmpfile, int format, char *ssifile
   ESL_SQFILE *sqfp = NULL;
   ESL_SQ     *sq   = esl_sq_CreateDigital(abc);
   uint16_t    fh   = 0;
-  int         nseq = 0;
   int         status;
 
   int         bpl, rpl;
  
-  sprintf(ssifile, "%s.ssi", tmpfile);
+  snprintf(ssifile, 32, "%s.ssi", tmpfile);  // 32 is the allocation size of ssifile, from main()
   if (esl_newssi_Open(ssifile, TRUE, &ns)                       != eslOK) esl_fatal(msg);
   if (esl_newssi_AddFile(ns, tmpfile, format, &fh)              != eslOK) esl_fatal(msg);
   if (esl_sqfile_OpenDigital(abc, tmpfile, format, NULL, &sqfp) != eslOK) esl_fatal(msg);
   while ((status = esl_sqio_ReadInfo(sqfp, sq)) == eslOK)
     {
-      nseq++;
       if (esl_newssi_AddKey(ns, sq->name, fh, sq->roff, sq->doff, sq->L)   != eslOK) esl_fatal(msg);
       if (sq->acc[0] != '\0' && esl_newssi_AddAlias(ns, sq->acc, sq->name) != eslOK) esl_fatal(msg);
       esl_sq_Reuse(sq);
@@ -2170,6 +2168,44 @@ utest_guess_mechanics(ESL_ALPHABET *abc, ESL_SQ **sqarr, int N)
     }
 }
 
+/* utest_guess_empty_seq()
+ * ML, 9 Oct 21
+ *
+ * Make sure that esl_sqfile_GuessAlphabet() returns eslNOALPHABET when
+ * it tries to guess the alphabet on files containing only empty sequences.
+ *
+ * Related to bugfix 441a4d3: sqascii_GuessAlphabet() did not handle
+ * the case where sqascii_ReadWindow() would return eslEOD on empty
+ * sequences, and returned an error instead of eslENOALPHABET.
+ */
+static void
+utest_guess_empty_seq()
+{
+  char       *msg         = "sqio guess_empty_seq unit test failure";
+  char        tmpfile[32];
+  ESL_SQ*     seqs[2];
+  FILE       *fp;
+  ESL_SQFILE *sqfp;
+  int         alphatype;
+
+  if ((seqs[0] = esl_sq_CreateFrom("seqs0", "", NULL, NULL, NULL)) == NULL) esl_fatal(msg);
+  if ((seqs[1] = esl_sq_CreateFrom("seqs1", "", NULL, NULL, NULL)) == NULL) esl_fatal(msg);
+
+  strcpy(tmpfile, "esltmpXXXXXX");
+  if (esl_tmpfile_named(tmpfile, &fp)                     != eslOK) esl_fatal(msg);
+  if (esl_sqio_Write(fp, seqs[0], eslSQFILE_FASTA, FALSE) != eslOK) esl_fatal(msg);
+  if (esl_sqio_Write(fp, seqs[1], eslSQFILE_FASTA, FALSE) != eslOK) esl_fatal(msg);
+  fclose(fp);
+
+  if (esl_sqfile_Open(tmpfile, eslSQFILE_FASTA, NULL, &sqfp) != eslOK) esl_fatal(msg);
+  if (esl_sqfile_GuessAlphabet(sqfp, &alphatype) != eslENOALPHABET)    esl_fatal(msg);
+  esl_sqfile_Close(sqfp);
+  remove(tmpfile);
+
+  esl_sq_Destroy(seqs[0]);
+  esl_sq_Destroy(seqs[1]);
+}
+
 #endif /*eslSQIO_TESTDRIVE*/
 /*------------------ end, unit tests ----------------------------*/
 
@@ -2183,7 +2219,7 @@ utest_guess_mechanics(ESL_ALPHABET *abc, ESL_SQ **sqarr, int N)
  * ./sqio_utest
  */
 #ifdef eslSQIO_TESTDRIVE
-#include "esl_config.h"
+#include <esl_config.h>
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -2260,6 +2296,7 @@ main(int argc, char **argv)
 
   utest_guess_mechanics(abc, sqarr, N);
   utest_write          (abc, sqarr, N, eslMSAFILE_STOCKHOLM);
+  utest_guess_empty_seq();
 
   for (i = 0; i < N; i++) esl_sq_Destroy(sqarr[i]);
   free(sqarr);
