@@ -4,7 +4,7 @@
  */
 #ifndef eslSTRETCHEXP_INCLUDED
 #define eslSTRETCHEXP_INCLUDED
-#include "esl_config.h"
+#include <esl_config.h>
 
 #include "esl_histogram.h"
 #include "esl_random.h"
