@@ -20,13 +20,13 @@
  *   17. P7_BUILDER:     configuration options for new HMM construction.
  *   18. Declaration of functions in HMMER's exposed API.
  *   
- * Also, see impl_{sse,vmx}/impl_{sse,vmx}.h for additional API
+ * Also, see impl_{sse,vmx,neon}/impl_{sse,vmx,neon}.h for additional API
  * specific to the acceleration layer; in particular, the P7_OPROFILE
  * structure for an optimized profile.
  */
 #ifndef P7_HMMERH_INCLUDED
 #define P7_HMMERH_INCLUDED
-#include "p7_config.h"
+#include <p7_config.h>
 
 #include <stdio.h>		
 #include <stddef.h>             // ptrdiff_t 
@@ -174,7 +174,7 @@ typedef struct p7_hmm_s {
   char    *desc;                 /* brief (1-line) description of model   (optional: NULL) */ /* String, \0-terminated   */
   char    *rf;                   /* reference line from alignment 1..M    (p7H_RF)         */ /* String; 0=' ', M+1='\0' */
   char    *mm;                   /* model mask line from alignment 1..M   (p7H_MM)         */ /* String; 0=' ', M+1='\0' */
-  char    *consensus;		         /* consensus residue line        1..M    (p7H_CONS)       */ /* String; 0=' ', M+1='\0' */
+  char    *consensus;		 /* consensus residue line        1..M    (p7H_CONS)       */ /* String; 0=' ', M+1='\0' */
   char    *cs;                   /* consensus structure line      1..M    (p7H_CS)         */ /* String; 0=' ', M+1='\0' */
   char    *ca;	                 /* consensus accessibility line  1..M    (p7H_CA)         */ /* String; 0=' ', M+1='\0' */
 
@@ -433,6 +433,7 @@ typedef struct p7_hmmfile_s {
 #endif
 
   char          errbuf[eslERRBUFSIZE];
+  char          rr_errbuf[eslERRBUFSIZE];  // p7_oprofile_ReadRest() uses this instead of errbuf, as a workaround for a thread race issue. See notes there.
 } P7_HMMFILE;
 
 /* note on <fname>, above:
@@ -821,7 +822,9 @@ typedef struct p7_hmm_window_list_s {
 /*****************************************************************
  * 14. Choice of vector implementation.
  *****************************************************************/
-#if   defined (eslENABLE_SSE)
+#if   defined (eslENABLE_NEON)
+#include "impl_neon/impl_neon.h"
+#elif defined (eslENABLE_SSE)
 #include "impl_sse/impl_sse.h"
 #elif defined (eslENABLE_VMX)
 #include "impl_vmx/impl_vmx.h"
@@ -1515,6 +1518,7 @@ extern int p7_Builder_MaxLength      (P7_HMM *hmm, double emit_thresh);
 /* p7_domain.c */
 extern P7_DOMAIN *p7_domain_Create_empty();
 extern void p7_domain_Destroy(P7_DOMAIN *obj);
+extern int p7_domain_Copy(const P7_DOMAIN *src, P7_DOMAIN *dst);
 extern int p7_domain_Serialize(const P7_DOMAIN *obj, uint8_t **buf, uint32_t *n, uint32_t *nalloc);
 extern int p7_domain_Deserialize(const uint8_t *buf, uint32_t *n, P7_DOMAIN *ret_obj);
 extern int p7_domain_TestSample(ESL_RAND64 *rng, P7_DOMAIN **ret_obj);
@@ -1547,6 +1551,7 @@ extern int     p7_gmx_DumpWindow(FILE *fp, P7_GMX *gx, int istart, int iend, int
 /* p7_hit.c */
 extern P7_HIT *p7_hit_Create_empty();
 extern void p7_hit_Destroy(P7_HIT *the_hit);
+extern int p7_hit_Copy(const P7_HIT *src, P7_HIT *dst);
 extern int p7_hit_Serialize(const P7_HIT *obj, uint8_t **buf, uint32_t *n, uint32_t *nalloc);
 extern int p7_hit_Deserialize(const uint8_t *buf, uint32_t *n, P7_HIT *ret_obj);
 extern int p7_hit_TestSample(ESL_RAND64 *rng, P7_HIT **ret_obj);
@@ -1590,10 +1595,8 @@ extern int     p7_hmm_CalculateOccupancy(const P7_HMM *hmm, float *mocc, float *
 
 
 /* p7_hmmfile.c */
-extern int  p7_hmmfile_OpenE    (const char *filename, char *env, P7_HMMFILE **ret_hfp, char *errbuf);
-extern int  p7_hmmfile_OpenENoDB(const char *filename, char *env, P7_HMMFILE **ret_hfp, char *errbuf);
-extern int  p7_hmmfile_Open     (const char *filename, char *env, P7_HMMFILE **ret_hfp); /* deprecated */
-extern int  p7_hmmfile_OpenNoDB (const char *filename, char *env, P7_HMMFILE **ret_hfp); /* deprecated */
+extern int  p7_hmmfile_Open      (const char *filename, char *env, P7_HMMFILE **ret_hfp, char *errbuf);
+extern int  p7_hmmfile_OpenNoDB  (const char *filename, char *env, P7_HMMFILE **ret_hfp, char *errbuf);
 extern int  p7_hmmfile_OpenBuffer(const char *buffer, int size, P7_HMMFILE **ret_hfp);
 extern void p7_hmmfile_Close(P7_HMMFILE *hfp);
 #ifdef HMMER_THREADS
@@ -1692,6 +1695,7 @@ extern void    p7_spensemble_Destroy(P7_SPENSEMBLE *sp);
 /* p7_tophits.c */
 extern P7_TOPHITS *p7_tophits_Create(void);
 extern int         p7_tophits_Grow(P7_TOPHITS *h);
+extern P7_TOPHITS *p7_tophits_Clone(const P7_TOPHITS *h);
 extern int         p7_tophits_CreateNextHit(P7_TOPHITS *h, P7_HIT **ret_hit);
 extern int         p7_tophits_Add(P7_TOPHITS *h,
 				  char *name, char *acc, char *desc, 
@@ -1802,7 +1806,7 @@ extern int fm_initConfigGeneric( FM_CFG *cfg, ESL_GETOPTS *go);
 /* fm_ssv.c */
 extern int p7_SSVFM_longlarget( P7_OPROFILE *om, float nu, P7_BG *bg, double F1,
                       const FM_DATA *fmf, const FM_DATA *fmb, FM_CFG *fm_cfg, const P7_SCOREDATA *ssvdata,
-                      int strands, P7_HMM_WINDOWLIST *windowlist);
+                      int strands, ESL_RANDOMNESS *r, P7_HMM_WINDOWLIST *windowlist);
 
 
 /* fm_sse.c */
