@@ -7,7 +7,7 @@
  *    4. Benchmark driver.
  *    5. Test driver.
  */
-#include "p7_config.h"
+#include <p7_config.h>
 
 #include <stdlib.h>
 #include <string.h>
@@ -56,6 +56,60 @@ p7_tophits_Create(void)
 }
 
 
+/* Function:  p7_tophits_Clone()
+ * Synopsis:  Create a duplicate of an existing <P7_TOPHITS> object.
+ *
+ * Purpose:   Creates a duplicate of the existing <P7_TOPHITS> object <h>.
+ *
+ * Returns:   ptr to the duplicate <P7_TOPHITS> object.
+ *
+ * Throws:    <NULL> on allocation failure.
+ */
+P7_TOPHITS *
+p7_tophits_Clone(const P7_TOPHITS *h)
+{
+  P7_TOPHITS *h2 = NULL;
+  int i;
+  int status;
+
+  ESL_ALLOC(h2, sizeof(P7_TOPHITS));
+  
+  h2->nreported = h->nreported;
+  h2->nincluded = h->nincluded;
+  h2->is_sorted_by_sortkey = h->is_sorted_by_sortkey;
+  h2->is_sorted_by_seqidx = h->is_sorted_by_seqidx;
+  
+  h2->N = h->N;
+  h2->Nalloc = h->N;
+  
+  h2->hit = NULL;
+  h2->unsrt = NULL;
+  
+  ESL_ALLOC(h2->hit,   sizeof(P7_HIT *) * h2->N);
+  ESL_ALLOC(h2->unsrt, sizeof(P7_HIT)   * h2->N);
+  
+  // set NULL pointers everywhere before allocating to avoid double free on error
+  for (i = 0; i < h2->N; i++) {
+    h2->unsrt[i].name = NULL;
+    h2->unsrt[i].acc = NULL;
+    h2->unsrt[i].desc = NULL;
+    h2->unsrt[i].dcl = NULL;
+  }
+  
+  // copy domains and update offsets in the sorted hit array
+  for (i = 0; i < h2->N; i++) {
+    if ((status = p7_hit_Copy(&(h->unsrt[i]), &(h2->unsrt[i]))) != eslOK) goto ERROR;
+    h2->hit[i] = h2->unsrt + (h->hit[i] - h->unsrt);
+  }
+  
+  return h2;
+
+ ERROR:
+  p7_tophits_Destroy(h2);
+  return NULL;
+}
+
+
 /* Function:  p7_tophits_Grow()
  * Synopsis:  Reallocates a larger hit list, if needed.
  *
@@ -276,58 +330,53 @@ hit_sorter_by_sortkey(const void *vh1, const void *vh2)
   }
 }
 
+/* used before duplicate hit removal in an nhmmer longtarget pipeline: */
 static int
 hit_sorter_by_seqidx_aliposition(const void *vh1, const void *vh2)
 {
-  P7_HIT *h1 = *((P7_HIT **) vh1);  /* don't ask. don't change. Don't Panic. */
-  P7_HIT *h2 = *((P7_HIT **) vh2);
+  P7_HIT  *h1 = *((P7_HIT **) vh1);  
+  P7_HIT  *h2 = *((P7_HIT **) vh2);
+  int64_t  s1, e1, s2, e2;
+  int      dir1, dir2;
 
   if      (h1->seqidx > h2->seqidx) return  1; /* first key, seq_idx (unique id for sequences), low to high */
   else if (h1->seqidx < h2->seqidx) return -1;
+
   // if on different strand, the positive strand goes first, else use position
-  int dir1 = (h1->dcl[0].iali < h1->dcl[0].jali ? 1 : -1);
-  int dir2 = (h2->dcl[0].iali < h2->dcl[0].jali ? 1 : -1);
+  s1 = h1->dcl[0].iali;  e1 = h1->dcl[0].jali;  if (s1 < e1) { dir1 = 1; } else { dir1 = -1; ESL_SWAP(s1, e1, int64_t); }
+  s2 = h2->dcl[0].iali;  e2 = h2->dcl[0].jali;  if (s2 < e2) { dir2 = 1; } else { dir2 = -1; ESL_SWAP(s2, e2, int64_t); }
 
   if (dir1 != dir2) return dir2; // so if dir1 is pos (1), and dir2 is neg (-1), this will return -1, placing h1 before h2;  otherwise, vice versa
 
-  if ( h1->dcl[0].iali == h2->dcl[0].iali) { 
-    if     (h1->dcl[0].jali < h2->dcl[0].jali) return  1; 
-    else if(h1->dcl[0].jali > h2->dcl[0].jali) return -1; 
-    else                                       return  0;
-  }
-  else { 
-    if     (h1->dcl[0].iali > h2->dcl[0].iali) return  1; 
-    else if(h1->dcl[0].iali < h2->dcl[0].iali) return -1;
-    else                                       return  0;
-  }
+  if      (s1 > s2) return  1;   // sort primarily from smallest to largest start pos
+  else if (s1 < s2) return -1;
+  else if (e1 < e2) return  1;   // secondarily, larger to smallest end position (i.e. longer hit first)
+  else if (e1 > e2) return -1;
+  else              return  0;
 }
 
+/* similarly, for nhmmscan longtarget pipeline: */
 static int
 hit_sorter_by_modelname_aliposition(const void *vh1, const void *vh2)
 {
-  P7_HIT *h1 = *((P7_HIT **) vh1);  /* don't ask. don't change. Don't Panic. */
-  P7_HIT *h2 = *((P7_HIT **) vh2);
+  P7_HIT  *h1 = *((P7_HIT **) vh1);  
+  P7_HIT  *h2 = *((P7_HIT **) vh2);
+  int64_t  s1, e1, s2, e2;
+  int      dir1, dir2;
+  int      res;
 
-  int res = esl_strcmp( h1->name, h2->name);
+  if  ( ( res = esl_strcmp(h1->name, h2->name))  != 0 ) return res; /* first key, seq_idx (unique id for sequences), low to high */
 
-  if  ( res != 0 ) return  res; /* first key, seq_idx (unique id for sequences), low to high */
+  s1 = h1->dcl[0].iali;  e1 = h1->dcl[0].jali;  if (s1 < e1) { dir1 = 1; } else { dir1 = -1; ESL_SWAP(s1, e1, int64_t); }
+  s2 = h2->dcl[0].iali;  e2 = h2->dcl[0].jali;  if (s2 < e2) { dir2 = 1; } else { dir2 = -1; ESL_SWAP(s2, e2, int64_t); }
 
-  // if on different strand, the positive strand goes first, else use position
-  int dir1 = (h1->dcl[0].iali < h1->dcl[0].jali ? 1 : -1);
-  int dir2 = (h2->dcl[0].iali < h2->dcl[0].jali ? 1 : -1);
+  if (dir1 != dir2) return dir2; 
 
-  if (dir1 != dir2) return dir2; // so if dir1 is pos (1), and dir2 is neg (-1), this will return -1, placing h1 before h2;  otherwise, vice versa
-
-  if ( h1->dcl[0].iali == h2->dcl[0].iali) { 
-    if     (h1->dcl[0].jali < h2->dcl[0].jali) return  1; 
-    else if(h1->dcl[0].jali > h2->dcl[0].jali) return -1; 
-    else                                       return  0;
-  }
-  else { 
-    if     (h1->dcl[0].iali > h2->dcl[0].iali) return  1; 
-    else if(h1->dcl[0].iali < h2->dcl[0].iali) return -1;
-    else                                       return  0;
-  }
+  if      (s1 > s2) return  1;   
+  else if (s1 < s2) return -1;
+  else if (e1 < e2) return  1;   
+  else if (e1 > e2) return -1;
+  else              return  0;
 }
 
 
@@ -355,11 +404,20 @@ p7_tophits_SortBySortkey(P7_TOPHITS *h)
 
 
 /* Function:  p7_tophits_SortBySeqidxAndAlipos()
- * Synopsis:  Sorts a hit list by sequence index and position in that
+ * Synopsis:  Sorts a hit list by sequence index and position for nhmmer.
  *            sequence at which the hit's first domain begins (used in nhmmer)
  *
- * Purpose:   Sorts a top hit list. After this call,
- *            <h->hit[i]> points to the i'th ranked
+ * Purpose: Sorts a top hit list, suitable for subsequent hit
+ *            duplicate removal by `p7_tophits_RemoveDuplicates()` in
+ *            an nhmmer longtarget pipeline: by sequence index, then
+ *            by strand (+ before - hits), then by smallest-to-largest
+ *            start position (in watson coords), then by
+ *            largest-to-smallest end position (in watson
+ *            coords). Correctness of logic of
+ *            `p7_tophits_RemoveDuplicates()` is sensitive to this
+ *            ordering.
+ * 
+ *            After this call, <h->hit[i]> points to the i'th ranked
  *            <P7_HIT> for all <h->N> hits.
  *
  * Returns:   <eslOK> on success.
@@ -378,12 +436,10 @@ p7_tophits_SortBySeqidxAndAlipos(P7_TOPHITS *h)
 }
 
 /* Function:  p7_tophits_SortByModelnameAndAlipos()
- * Synopsis:  Sorts a hit list by model name and position in the query sequence
- *            sequence at which the hit's first domain begins (used in nhmmscan)
+ * Synopsis:  Sorts a hit list by model name and position for nhmmscan.
  *
- * Purpose:   Sorts a top hit list. After this call,
- *            <h->hit[i]> points to the i'th ranked
- *            <P7_HIT> for all <h->N> hits.
+ * Purpose:   Like `p7_tophits_SortBySeqidxAndAlipos()` but for
+ *            nhmmscan, which sorts on model name not target seq idx.
  *
  * Returns:   <eslOK> on success.
  */
@@ -497,13 +553,14 @@ p7_tophits_GetMaxPositionLength(P7_TOPHITS *h)
   int64_t i;
   int max = 0;
   int n;
-  char buffer [13];
+  char buffer [26];  // SRE: this was [13], not sufficient for int64. 
+                     //      rule of thumb: 3*sizeof(int) + 2
 
   for (i = 0; i < h->N; i++) {
     if (h->unsrt[i].dcl[0].iali > 0) {
-      n = sprintf (buffer, "%" PRId64 "", h->unsrt[i].dcl[0].iali);
+      n = snprintf (buffer, 26, "%" PRId64 "", h->unsrt[i].dcl[0].iali); // 26 matches buffer[26] allocation
       max = ESL_MAX(n, max);
-      n = sprintf (buffer, "%" PRId64 "", h->unsrt[i].dcl[0].jali);
+      n = snprintf (buffer, 26, "%" PRId64 "", h->unsrt[i].dcl[0].jali);
       max = ESL_MAX(n, max);
     }
   }
@@ -723,14 +780,15 @@ workaround_bug_h74(P7_TOPHITS *th)
 /* Function:  p7_tophits_ComputeNhmmerEvalues()
  * Synopsis:  Compute e-values based on pvalues and window sizes.
  *
- * Purpose:   After nhmmer pipeline has completed, the th object contains
- *               hits where the p-values haven't yet been converted to
- *               e-values. That modification depends on an established
- *               number of sequences. In nhmmer, this is computed as N/W,
- *               for a database of N residues, where W is some standardized
- *               window length (nhmmer passes om->max_length). E-values are
- *               set here based on that formula. We also set the sortkey so
- *               the output will be sorted correctly.
+ * Purpose:   After nhmmer pipeline has completed, the <th> object
+ *            contains hits where the P-values haven't yet been
+ *            converted to E-values. That modification depends on an
+ *            established number of sequences. In nhmmer, this is
+ *            computed as N/W, for a database of N residues, where W
+ *            is some standardized window length (nhmmer passes
+ *            om->max_length). E-values are set here based on that
+ *            formula. We also set the sortkey so the output will be
+ *            sorted correctly.
  *
  * Returns:   <eslOK> on success.
  */
@@ -769,8 +827,6 @@ p7_tophits_RemoveDuplicates(P7_TOPHITS *th, int using_bit_cutoffs)
   int     s_i, s_j, e_i, e_j, dir_i, dir_j, len_i, len_j;
   int     intersect_alistart, intersect_aliend, intersect_alilen;
   int     intersect_hmmstart, intersect_hmmend, intersect_hmmlen;
-  //int64_t sub_i, sub_j;
-  int     tmp;
   double  p_i, p_j;
   int remove;
 
@@ -779,33 +835,20 @@ p7_tophits_RemoveDuplicates(P7_TOPHITS *th, int using_bit_cutoffs)
   j=0;
   for (i = 1; i < th->N; i++)
   {
-
-      //sub_j = th->hit[j]->subseq_start;
-      p_j = th->hit[j]->lnP;
-      s_j = th->hit[j]->dcl[0].iali;
-      e_j = th->hit[j]->dcl[0].jali;
+      p_j   = th->hit[j]->lnP;
+      s_j   = th->hit[j]->dcl[0].iali;
+      e_j   = th->hit[j]->dcl[0].jali;
       dir_j = (s_j < e_j ? 1 : -1);
-      if (dir_j == -1) {
-        tmp = s_j;
-        s_j = e_j;
-        e_j = tmp;
-      }
+      if (dir_j == -1) ESL_SWAP(s_j, e_j, int);
       len_j = e_j - s_j + 1 ;
 
-
-      //sub_i = th->hit[i]->subseq_start;
-      p_i = th->hit[i]->lnP;
-      s_i = th->hit[i]->dcl[0].iali;
-      e_i = th->hit[i]->dcl[0].jali;
+      p_i   = th->hit[i]->lnP;
+      s_i   = th->hit[i]->dcl[0].iali;
+      e_i   = th->hit[i]->dcl[0].jali;
       dir_i = (s_i < e_i ? 1 : -1);
-      if (dir_i == -1) {
-        tmp = s_i;
-        s_i = e_i;
-        e_i = tmp;
-      }
+      if (dir_i == -1) ESL_SWAP(s_i, e_i, int);
       len_i = e_i - s_i + 1 ;
 
-
       // these will only matter if seqidx and strand are the same
       intersect_alistart  = s_i>s_j ? s_i : s_j;
       intersect_aliend    = e_i<e_j ? e_i : e_j;
@@ -813,19 +856,18 @@ p7_tophits_RemoveDuplicates(P7_TOPHITS *th, int using_bit_cutoffs)
 
       intersect_hmmstart = (th->hit[i]->dcl[0].ad->hmmfrom > th->hit[j]->dcl[0].ad->hmmfrom) ? th->hit[i]->dcl[0].ad->hmmfrom : th->hit[j]->dcl[0].ad->hmmfrom;
       intersect_hmmend   = (th->hit[i]->dcl[0].ad->hmmto   < th->hit[j]->dcl[0].ad->hmmto)   ? th->hit[i]->dcl[0].ad->hmmto : th->hit[j]->dcl[0].ad->hmmto;
-      intersect_hmmlen = intersect_hmmend - intersect_hmmstart + 1;
+      intersect_hmmlen   = intersect_hmmend - intersect_hmmstart + 1;
 
-      if ( esl_strcmp(th->hit[i]->name, th->hit[i-1]->name) == 0  && //same model
-          th->hit[i]->seqidx ==  th->hit[i-1]->seqidx  && //same source sequence
-           dir_i == dir_j && // only bother removing if the overlapping hits are on the same strand
-           intersect_hmmlen > 0 && //only if they're both hitting similar parts of the model
+      if ( esl_strcmp(th->hit[i]->name, th->hit[i-1]->name) == 0  && // same model
+           th->hit[i]->seqidx ==  th->hit[i-1]->seqidx  &&           // same source sequence
+           dir_i == dir_j &&                                         // only bother removing if the overlapping hits are on the same strand
+           intersect_hmmlen > 0 &&                                   // only if they're both hitting similar parts of the model
            (
-               ( s_i >= s_j-3 && s_i <= s_j+3) ||  // at least one side is essentially flush
+               ( s_i >= s_j-3 && s_i <= s_j+3) ||     // at least one side is essentially flush
                ( e_i >= e_j-3 && e_i <= e_j+3) ||
                ( intersect_alilen >= len_i * 0.95) || // or one of the hits covers >90% of the other
                ( intersect_alilen >= len_j * 0.95)
-           )
-      )
+	   ))
       {
         /* Force one to go unreported.  I prefer to keep the one with the
          * better e-value.  This addresses two issues
@@ -846,16 +888,14 @@ p7_tophits_RemoveDuplicates(P7_TOPHITS *th, int using_bit_cutoffs)
         remove = p_i < p_j ? j : i;
 
         th->hit[remove]->flags |= p7_IS_DUPLICATE;
-        if (using_bit_cutoffs) {
-          //report/include flags were already included, need to remove them here
+        if (using_bit_cutoffs) { // report/include flags were already included, need to remove them here
           th->hit[remove]->flags &= ~p7_IS_REPORTED;
           th->hit[remove]->flags &= ~p7_IS_INCLUDED;
         }
 
-        j = remove == j ? i : j;
-      } else {
-        j = i;
+        j = (remove == j ? i : j);
       }
+      else j = i; 
   }
   return eslOK;
 }
@@ -948,12 +988,15 @@ p7_tophits_Threshold(P7_TOPHITS *th, P7_PIPELINE *pli)
   }
 
   /* Count the reported, included domains */
-  for (h = 0; h < th->N; h++)  
+  for (h = 0; h < th->N; h++) {
+    th->hit[h]->nreported = 0;
+    th->hit[h]->nincluded = 0;
     for (d = 0; d < th->hit[h]->ndom; d++)
     {
         if (th->hit[h]->dcl[d].is_reported) th->hit[h]->nreported++;
         if (th->hit[h]->dcl[d].is_included) th->hit[h]->nincluded++;
     }
+  }
 
   workaround_bug_h74(th);  /* blech. This function is defined above; see commentary and crossreferences there. */
 
@@ -1776,7 +1819,6 @@ p7_tophits_TabularXfam(FILE *ofp, char *qname, char *qacc, P7_TOPHITS *th, P7_PI
   int         tnamew     = ESL_MAX(20, p7_tophits_GetMaxNameLength(th));
   int         taccw      = ESL_MAX(20, p7_tophits_GetMaxAccessionLength(th));
   int         qnamew     = ESL_MAX(20, strlen(qname));
-  int         ndom       = 0;
   int         posw       = (pli->long_targets ? ESL_MAX(7, p7_tophits_GetMaxPositionLength(th)) : 0);
   int         h,d;
   int         status;
@@ -1798,21 +1840,21 @@ p7_tophits_TabularXfam(FILE *ofp, char *qname, char *qacc, P7_TOPHITS *th, P7_PI
       {
           //d    = th->hit[h]->best_domain;
           if (fprintf(ofp, "%-*s  %-*s %-*s %6.1f %9.2g %5.1f %7d %7d %s %*" PRId64 " %*" PRId64 " %*" PRId64 " %*" PRId64 " %*" PRId64 "   %s\n",
-          tnamew, th->hit[h]->name,
-          taccw, ( pli->mode == p7_SCAN_MODELS ? th->hit[h]->acc : qacc ),
-          qnamew, qname,
-          th->hit[h]->score,
-          exp(th->hit[h]->lnP),
-          th->hit[h]->dcl[0].dombias * eslCONST_LOG2R, /* convert nats to bits at last moment */
-          th->hit[h]->dcl[0].ad->hmmfrom,
-          th->hit[h]->dcl[0].ad->hmmto,
-          (th->hit[h]->dcl[0].iali < th->hit[h]->dcl[0].jali ? "   +  "  :  "   -  "),
-          posw, th->hit[h]->dcl[0].iali,
-          posw, th->hit[h]->dcl[0].jali,
-          posw, th->hit[h]->dcl[0].ienv,
-          posw, th->hit[h]->dcl[0].jenv,
-          posw, th->hit[h]->dcl[0].ad->L,
-          th->hit[h]->desc == NULL ?  "-" : th->hit[h]->desc) < 0)
+		      tnamew, th->hit[h]->name,
+		      taccw, ( pli->mode == p7_SCAN_MODELS ? (th->hit[h]->acc ? th->hit[h]->acc : "-") : ((qacc && qacc[0] != '\0') ? qacc : "-")),
+		      qnamew, qname,
+		      th->hit[h]->score,
+		      exp(th->hit[h]->lnP),
+		      th->hit[h]->dcl[0].dombias * eslCONST_LOG2R, /* convert nats to bits at last moment */
+		      th->hit[h]->dcl[0].ad->hmmfrom,
+		      th->hit[h]->dcl[0].ad->hmmto,
+		      (th->hit[h]->dcl[0].iali < th->hit[h]->dcl[0].jali ? "   +  "  :  "   -  "),
+		      posw, th->hit[h]->dcl[0].iali,
+		      posw, th->hit[h]->dcl[0].jali,
+		      posw, th->hit[h]->dcl[0].ienv,
+		      posw, th->hit[h]->dcl[0].jenv,
+		      posw, th->hit[h]->dcl[0].ad->L,
+		      th->hit[h]->desc == NULL ?  "-" : th->hit[h]->desc) < 0)
             ESL_XEXCEPTION_SYS(eslEWRITE, "xfam tabular output: write failed");
       }
   }
@@ -1840,10 +1882,6 @@ p7_tophits_TabularXfam(FILE *ofp, char *qname, char *qacc, P7_TOPHITS *th, P7_PI
           th->hit[h]->pre_score - th->hit[h]->score, /* bias correction */
           (th->hit[h]->desc == NULL ? "-" : th->hit[h]->desc)) < 0)
             ESL_XEXCEPTION_SYS(eslEWRITE, "xfam tabular output: write failed");
-
-          for (d = 0; d < th->hit[h]->ndom; d++)
-            if (th->hit[h]->dcl[d].is_reported)
-              ndom ++;
         }
       }
       if (fprintf(ofp, "\n") < 0) ESL_XEXCEPTION_SYS(eslEWRITE, "xfam tabular output: write failed");
@@ -2048,7 +2086,7 @@ p7_tophits_TabularTail(FILE *ofp, const char *progname, enum p7_pipemodes_e pipe
   
   If needed, we do have opportunity for optimization, however - especially in memory handling.
  */
-#include "p7_config.h"
+#include <p7_config.h>
 
 #include "easel.h"
 #include "esl_getopts.h"
@@ -2135,7 +2173,7 @@ main(int argc, char **argv)
   gcc -o tophits_utest -std=gnu99 -g -O2 -I. -L. -I../easel -L../easel -Dp7TOPHITS_TESTDRIVE p7_tophits.c -lhmmer -leasel -lm 
   ./tophits_test
 */
-#include "p7_config.h"
+#include <p7_config.h>
 
 #include "easel.h"
 #include "esl_getopts.h"
